@@ -28,7 +28,7 @@ def infer_type(string_var):
     return evaluated
 
 
-def json_to_py(json):
+def json_to_py(json, replace_comma_decimal=True):
     """Take json and eval it from strings.
     If string to string, if float to float, if object then to dict.
 
@@ -36,6 +36,8 @@ def json_to_py(json):
 
     Args:
         json (dict): JSON with various formats as string.
+        replace_comma_decimal (bool): Some countries use comma as decimal separator (e.g. 12,3).
+            If True, comma replaced with dot (if not converted to number string remain untouched)
 
     Returns:
         dict: Python dictionary with correct types.
@@ -46,6 +48,10 @@ def json_to_py(json):
     evaluated = json.copy()
 
     for i, j in json.items():
+
+        if replace_comma_decimal and isinstance(j, str) and "(" not in j and "[" not in j:
+            j = j.replace(",", ".")
+
         try:
             evaluated[i] = ast.literal_eval(j)
         except Exception:
